import { resolve } from 'node:path'
import { merge } from 'lodash-es'
import { defineConfig, defineViteConfig, externalizeDepsPlugin } from 'electron-vite'

export default defineConfig({
    main: {
        plugins: [externalizeDepsPlugin()],
        build: {
            rollupOptions: {
                input: {
                    index: resolve(__dirname, 'electron/main/index.ts'),
                },
            },
        },
    },
    preload: {
        plugins: [externalizeDepsPlugin()],
        build: {
            rollupOptions: {
                input: {
                    index: resolve(__dirname, 'electron/preload/index.ts'),
                },
            },
        },
    },
    renderer: defineViteConfig(async (env) => {
        const renderConfig = (await import('./vite.config')).default
        const config = renderConfig(env)

        return merge(config, {
            build: {
                target: 'chrome80',
                rollupOptions: {
                    input: {
                        index: resolve(__dirname, 'index.html'),
                    },
                },
            },
        })
    }),
})
